# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ucb
from __future__ import annotations
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XInteractionHandlerSupplier(XInterface_8f010a43):
    """
    This interface should be implemented by an internal XCommandEnvironment that can not supply an com.sun.star.task.XInteractionHandler, but instead wants interaction requests to be handled by other internal error handling mechanism.

    See Also:
        `API XInteractionHandlerSupplier <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ucb_1_1XInteractionHandlerSupplier.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.XInteractionHandlerSupplier'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.ucb.XInteractionHandlerSupplier'

    @abstractmethod
    def hasInteractionHandler(self) -> bool:
        """
        Returns whether an com.sun.star.task.XInteractionHandler can be supplied.
        """
        ...

__all__ = ['XInteractionHandlerSupplier']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from contextlib import suppress
import warnings
warnings.filterwarnings('module')
warnings.warn('The cssdyn namespace is deprecated. Use dyn instead.', DeprecationWarning, stacklevel=2)

with suppress(ImportError):
    from ...dyn.chart2.axis import Axis as Axis
with suppress(ImportError):
    from ...dyn.chart2.axis_orientation import AxisOrientation as AxisOrientation
with suppress(ImportError):
    from ...dyn.chart2.axis_type import AxisType as AxisType
with suppress(ImportError):
    from ...dyn.chart2.axis_type import AxisTypeEnum as AxisTypeEnum
with suppress(ImportError):
    from ...dyn.chart2.candle_stick_chart_type import CandleStickChartType as CandleStickChartType
with suppress(ImportError):
    from ...dyn.chart2.cartesian_coordinate_system2d import CartesianCoordinateSystem2d as CartesianCoordinateSystem2d
with suppress(ImportError):
    from ...dyn.chart2.cartesian_coordinate_system3d import CartesianCoordinateSystem3d as CartesianCoordinateSystem3d
with suppress(ImportError):
    from ...dyn.chart2.chart_document import ChartDocument as ChartDocument
with suppress(ImportError):
    from ...dyn.chart2.chart_document_wrapper import ChartDocumentWrapper as ChartDocumentWrapper
with suppress(ImportError):
    from ...dyn.chart2.chart_type import ChartType as ChartType
with suppress(ImportError):
    from ...dyn.chart2.chart_type_manager import ChartTypeManager as ChartTypeManager
with suppress(ImportError):
    from ...dyn.chart2.chart_type_template import ChartTypeTemplate as ChartTypeTemplate
with suppress(ImportError):
    from ...dyn.chart2.coordinate_system import CoordinateSystem as CoordinateSystem
with suppress(ImportError):
    from ...dyn.chart2.coordinate_system_type import CoordinateSystemType as CoordinateSystemType
with suppress(ImportError):
    from ...dyn.chart2.coordinate_system_type_id import CoordinateSystemTypeID as CoordinateSystemTypeID
with suppress(ImportError):
    from ...dyn.chart2.curve_style import CurveStyle as CurveStyle
with suppress(ImportError):
    from ...dyn.chart2.data_point import DataPoint as DataPoint
with suppress(ImportError):
    from ...dyn.chart2.data_point_custom_label_field import DataPointCustomLabelField as DataPointCustomLabelField
with suppress(ImportError):
    from ...dyn.chart2.data_point_custom_label_field_type import DataPointCustomLabelFieldType as DataPointCustomLabelFieldType
with suppress(ImportError):
    from ...dyn.chart2.data_point_geometry3_d import DataPointGeometry3D as DataPointGeometry3D
with suppress(ImportError):
    from ...dyn.chart2.data_point_geometry3_d import DataPointGeometry3DEnum as DataPointGeometry3DEnum
with suppress(ImportError):
    from ...dyn.chart2.data_point_label import DataPointLabel as DataPointLabel
with suppress(ImportError):
    from ...dyn.chart2.data_point_properties import DataPointProperties as DataPointProperties
with suppress(ImportError):
    from ...dyn.chart2.data_series import DataSeries as DataSeries
with suppress(ImportError):
    from ...dyn.chart2.diagram import Diagram as Diagram
with suppress(ImportError):
    from ...dyn.chart2.error_bar import ErrorBar as ErrorBar
with suppress(ImportError):
    from ...dyn.chart2.exponential_regression_curve import ExponentialRegressionCurve as ExponentialRegressionCurve
with suppress(ImportError):
    from ...dyn.chart2.exponential_scaling import ExponentialScaling as ExponentialScaling
with suppress(ImportError):
    from ...dyn.chart2.fill_bitmap import FillBitmap as FillBitmap
with suppress(ImportError):
    from ...dyn.chart2.formatted_string import FormattedString as FormattedString
with suppress(ImportError):
    from ...dyn.chart2.grid_properties import GridProperties as GridProperties
with suppress(ImportError):
    from ...dyn.chart2.increment_data import IncrementData as IncrementData
with suppress(ImportError):
    from ...dyn.chart2.legend import Legend as Legend
with suppress(ImportError):
    from ...dyn.chart2.legend_position import LegendPosition as LegendPosition
with suppress(ImportError):
    from ...dyn.chart2.light_source import LightSource as LightSource
with suppress(ImportError):
    from ...dyn.chart2.linear_regression_curve import LinearRegressionCurve as LinearRegressionCurve
with suppress(ImportError):
    from ...dyn.chart2.linear_scaling import LinearScaling as LinearScaling
with suppress(ImportError):
    from ...dyn.chart2.logarithmic_regression_curve import LogarithmicRegressionCurve as LogarithmicRegressionCurve
with suppress(ImportError):
    from ...dyn.chart2.logarithmic_scaling import LogarithmicScaling as LogarithmicScaling
with suppress(ImportError):
    from ...dyn.chart2.logic_target_model import LogicTargetModel as LogicTargetModel
with suppress(ImportError):
    from ...dyn.chart2.moving_average_regression_curve import MovingAverageRegressionCurve as MovingAverageRegressionCurve
with suppress(ImportError):
    from ...dyn.chart2.moving_average_type import MovingAverageType as MovingAverageType
with suppress(ImportError):
    from ...dyn.chart2.moving_average_type import MovingAverageTypeEnum as MovingAverageTypeEnum
with suppress(ImportError):
    from ...dyn.chart2.pie_chart_offset_mode import PieChartOffsetMode as PieChartOffsetMode
with suppress(ImportError):
    from ...dyn.chart2.polar_coordinate_system2d import PolarCoordinateSystem2d as PolarCoordinateSystem2d
with suppress(ImportError):
    from ...dyn.chart2.polar_coordinate_system3d import PolarCoordinateSystem3d as PolarCoordinateSystem3d
with suppress(ImportError):
    from ...dyn.chart2.polynomial_regression_curve import PolynomialRegressionCurve as PolynomialRegressionCurve
with suppress(ImportError):
    from ...dyn.chart2.potential_regression_curve import PotentialRegressionCurve as PotentialRegressionCurve
with suppress(ImportError):
    from ...dyn.chart2.power_scaling import PowerScaling as PowerScaling
with suppress(ImportError):
    from ...dyn.chart2.property_pool import PropertyPool as PropertyPool
with suppress(ImportError):
    from ...dyn.chart2.regression_curve import RegressionCurve as RegressionCurve
with suppress(ImportError):
    from ...dyn.chart2.regression_curve_equation import RegressionCurveEquation as RegressionCurveEquation
with suppress(ImportError):
    from ...dyn.chart2.regression_equation import RegressionEquation as RegressionEquation
with suppress(ImportError):
    from ...dyn.chart2.relative_position import RelativePosition as RelativePosition
with suppress(ImportError):
    from ...dyn.chart2.relative_size import RelativeSize as RelativeSize
with suppress(ImportError):
    from ...dyn.chart2.scale_data import ScaleData as ScaleData
with suppress(ImportError):
    from ...dyn.chart2.scaling import Scaling as Scaling
with suppress(ImportError):
    from ...dyn.chart2.stacking_direction import StackingDirection as StackingDirection
with suppress(ImportError):
    from ...dyn.chart2.standard_diagram_creation_parameters import StandardDiagramCreationParameters as StandardDiagramCreationParameters
with suppress(ImportError):
    from ...dyn.chart2.sub_increment import SubIncrement as SubIncrement
with suppress(ImportError):
    from ...dyn.chart2.symbol import Symbol as Symbol
with suppress(ImportError):
    from ...dyn.chart2.symbol_style import SymbolStyle as SymbolStyle
with suppress(ImportError):
    from ...dyn.chart2.tickmark_style import TickmarkStyle as TickmarkStyle
with suppress(ImportError):
    from ...dyn.chart2.tickmark_style import TickmarkStyleEnum as TickmarkStyleEnum
with suppress(ImportError):
    from ...dyn.chart2.title import Title as Title
with suppress(ImportError):
    from ...dyn.chart2.transparency_style import TransparencyStyle as TransparencyStyle
with suppress(ImportError):
    from ...dyn.chart2.x_any_description_access import XAnyDescriptionAccess as XAnyDescriptionAccess
with suppress(ImportError):
    from ...dyn.chart2.x_axis import XAxis as XAxis
with suppress(ImportError):
    from ...dyn.chart2.x_chart_document import XChartDocument as XChartDocument
with suppress(ImportError):
    from ...dyn.chart2.x_chart_shape import XChartShape as XChartShape
with suppress(ImportError):
    from ...dyn.chart2.x_chart_shape_container import XChartShapeContainer as XChartShapeContainer
with suppress(ImportError):
    from ...dyn.chart2.x_chart_type import XChartType as XChartType
with suppress(ImportError):
    from ...dyn.chart2.x_chart_type_container import XChartTypeContainer as XChartTypeContainer
with suppress(ImportError):
    from ...dyn.chart2.x_chart_type_manager import XChartTypeManager as XChartTypeManager
with suppress(ImportError):
    from ...dyn.chart2.x_chart_type_template import XChartTypeTemplate as XChartTypeTemplate
with suppress(ImportError):
    from ...dyn.chart2.x_color_scheme import XColorScheme as XColorScheme
with suppress(ImportError):
    from ...dyn.chart2.x_coordinate_system import XCoordinateSystem as XCoordinateSystem
with suppress(ImportError):
    from ...dyn.chart2.x_coordinate_system_container import XCoordinateSystemContainer as XCoordinateSystemContainer
with suppress(ImportError):
    from ...dyn.chart2.x_data_point_custom_label_field import XDataPointCustomLabelField as XDataPointCustomLabelField
with suppress(ImportError):
    from ...dyn.chart2.x_data_provider_access import XDataProviderAccess as XDataProviderAccess
with suppress(ImportError):
    from ...dyn.chart2.x_data_series import XDataSeries as XDataSeries
with suppress(ImportError):
    from ...dyn.chart2.x_data_series_container import XDataSeriesContainer as XDataSeriesContainer
with suppress(ImportError):
    from ...dyn.chart2.x_default_size_transmitter import XDefaultSizeTransmitter as XDefaultSizeTransmitter
with suppress(ImportError):
    from ...dyn.chart2.x_diagram import XDiagram as XDiagram
with suppress(ImportError):
    from ...dyn.chart2.x_diagram_provider import XDiagramProvider as XDiagramProvider
with suppress(ImportError):
    from ...dyn.chart2.x_formatted_string import XFormattedString as XFormattedString
with suppress(ImportError):
    from ...dyn.chart2.x_formatted_string2 import XFormattedString2 as XFormattedString2
with suppress(ImportError):
    from ...dyn.chart2.x_internal_data_provider import XInternalDataProvider as XInternalDataProvider
with suppress(ImportError):
    from ...dyn.chart2.x_labeled import XLabeled as XLabeled
with suppress(ImportError):
    from ...dyn.chart2.x_legend import XLegend as XLegend
with suppress(ImportError):
    from ...dyn.chart2.x_regression_curve import XRegressionCurve as XRegressionCurve
with suppress(ImportError):
    from ...dyn.chart2.x_regression_curve_calculator import XRegressionCurveCalculator as XRegressionCurveCalculator
with suppress(ImportError):
    from ...dyn.chart2.x_regression_curve_container import XRegressionCurveContainer as XRegressionCurveContainer
with suppress(ImportError):
    from ...dyn.chart2.x_scaling import XScaling as XScaling
with suppress(ImportError):
    from ...dyn.chart2.x_target import XTarget as XTarget
with suppress(ImportError):
    from ...dyn.chart2.x_time_based import XTimeBased as XTimeBased
with suppress(ImportError):
    from ...dyn.chart2.x_title import XTitle as XTitle
with suppress(ImportError):
    from ...dyn.chart2.x_titled import XTitled as XTitled



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.frame
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_status_listener import XStatusListener as XStatusListener_e2740d35
from ..lang.x_component import XComponent as XComponent_98dc0ab5
from ..lang.x_initialization import XInitialization as XInitialization_d46c0cca
from ..util.x_updatable import XUpdatable as XUpdatable_9a420ab0
if typing.TYPE_CHECKING:
    from ..awt.mouse_event import MouseEvent as MouseEvent_8f430a5f
    from ..awt.point import Point as Point_5fb2085e
    from ..awt.rectangle import Rectangle as Rectangle_84b109e9
    from ..awt.x_graphics import XGraphics as XGraphics_842309dd

class XStatusbarController(XStatusListener_e2740d35, XComponent_98dc0ab5, XInitialization_d46c0cca, XUpdatable_9a420ab0):
    """
    interface to be implemented by a component offering a more complex user interface to users within a status bar.
    
    A generic status bar field is represented as a simple text field. A status bar controller can be added to a Statusbar and provide information or functions with a more sophisticated user interface.A typical example for status bar controller is a zoom chooser. It shows the current zoom and provides general zoom levels on a pop-up menu that can be activated by a mouse action for context menus.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XStatusbarController <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XStatusbarController.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame'
    __ooo_full_ns__: str = 'com.sun.star.frame.XStatusbarController'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.frame.XStatusbarController'

    @abstractmethod
    def click(self, aPos: Point_5fb2085e) -> None:
        """
        is called by a status bar if the user clicked with mouse into the field of the corresponding control.
        """
        ...
    @abstractmethod
    def command(self, aPos: Point_5fb2085e, nCommand: int, bMouseEvent: bool, aData: object) -> None:
        """
        is called by a status bar if a command event is available for a controller.
        """
        ...
    @abstractmethod
    def doubleClick(self, aPos: Point_5fb2085e) -> None:
        """
        is called by a status bar if the user double-clicked with mouse into the field of the corresponding control.
        """
        ...
    @abstractmethod
    def mouseButtonDown(self, aMouseEvent: MouseEvent_8f430a5f) -> bool:
        """
        is called by a status bar if the mouse position is within the controller and a mouse button has been pressed.
        
        If the controller has captured the mouse input this function is also called when the mouse position is not within the controller.
        """
        ...
    @abstractmethod
    def mouseButtonUp(self, aMouseEvent: MouseEvent_8f430a5f) -> bool:
        """
        is called by a status bar if the mouse position is within the controller and a mouse button has been released.
        
        If the controller has captured the mouse input this function is also called when the mouse position is not within the controller.
        """
        ...
    @abstractmethod
    def mouseMove(self, aMouseEvent: MouseEvent_8f430a5f) -> bool:
        """
        is called by a status bar if the mouse position is within the controller and a mouse has been moved.
        
        If the controller has captured the mouse input this function is also called when the mouse position is not within the controller.
        """
        ...
    @abstractmethod
    def paint(self, xGraphics: XGraphics_842309dd, OutputRectangle: Rectangle_84b109e9, nStyle: int) -> None:
        """
        is called by a status bar if the controller has to update the visual representation.
        """
        ...

__all__ = ['XStatusbarController']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.rendering


class PanoseSerifStyle(object):
    """
    Const Class


    See Also:
        `API PanoseSerifStyle <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1rendering_1_1PanoseSerifStyle.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.rendering'
    __ooo_full_ns__: str = 'com.sun.star.rendering.PanoseSerifStyle'
    __ooo_type_name__: str = 'const'

    ANYTHING = 0
    NO_FIT = 1
    COVE = 2
    OBTUSE_COVE = 3
    SQUARE_COVE = 4
    OBTUSE_SQUARE_COVE = 5
    SQUARE = 6
    THIN = 7
    BONE = 8
    EXAGGERATED = 9
    TRIANGLE = 10
    NORMAL_SANS = 11
    OBTUSE_SANS = 12
    PERP_SANS = 13
    FLARED = 14
    ROUNDED = 15

__all__ = ['PanoseSerifStyle']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.xml.xpath
# Libre Office Version: 7.4
from __future__ import annotations
from typing import cast, TYPE_CHECKING
from enum import Enum
if TYPE_CHECKING:
    from com.sun.star.xml.xpath.XPathObjectType import XPathObjectTypeProto

class XPathObjectType(Enum):
    """
    Enum Class

    ENUM XPathObjectType

    See Also:
        `API XPathObjectType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1xml_1_1xpath.html#a4e7de3ae7d09203486b85490e0a6f1a3>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.xpath'
    __ooo_full_ns__: str = 'com.sun.star.xml.xpath.XPathObjectType'
    __ooo_type_name__: str = 'enum'

    @property
    def typeName(self) -> str:
        return 'com.sun.star.xml.xpath.XPathObjectType'

    XPATH_BOOLEAN = cast("XPathObjectTypeProto", 'XPATH_BOOLEAN')
    """
    """
    XPATH_LOCATIONSET = cast("XPathObjectTypeProto", 'XPATH_LOCATIONSET')
    """
    """
    XPATH_NODESET = cast("XPathObjectTypeProto", 'XPATH_NODESET')
    """
    """
    XPATH_NUMBER = cast("XPathObjectTypeProto", 'XPATH_NUMBER')
    """
    """
    XPATH_POINT = cast("XPathObjectTypeProto", 'XPATH_POINT')
    """
    """
    XPATH_RANGE = cast("XPathObjectTypeProto", 'XPATH_RANGE')
    """
    """
    XPATH_STRING = cast("XPathObjectTypeProto", 'XPATH_STRING')
    """
    """
    XPATH_UNDEFINED = cast("XPathObjectTypeProto", 'XPATH_UNDEFINED')
    """
    """
    XPATH_USERS = cast("XPathObjectTypeProto", 'XPATH_USERS')
    """
    """
    XPATH_XSLT_TREE = cast("XPathObjectTypeProto", 'XPATH_XSLT_TREE')
    """
    """

__all__ = ['XPathObjectType']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.io
from __future__ import annotations
from abc import abstractproperty
from .x_seekable import XSeekable as XSeekable_79540954
from .x_stream import XStream as XStream_678908a4

class XTempFile(XSeekable_79540954, XStream_678908a4):
    """
    This interface offers access to temp files.

    See Also:
        `API XTempFile <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1io_1_1XTempFile.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.io'
    __ooo_full_ns__: str = 'com.sun.star.io.XTempFile'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.io.XTempFile'

    @abstractproperty
    def RemoveFile(self) -> bool:
        """
        This attribute controls whether the file will be automatically removed on object destruction.
        """
        ...

    @abstractproperty
    def ResourceName(self) -> str:
        """
        This attribute specifies the temp file name.
        """
        ...

    @abstractproperty
    def Uri(self) -> str:
        """
        This attribute specifies the URL of the temp file.
        """
        ...


__all__ = ['XTempFile']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing.framework
from __future__ import annotations
from abc import abstractmethod
from .x_resource_id import XResourceId as XResourceId_5be3103d

class ResourceId(XResourceId_5be3103d):
    """
    Service Class

    The ResourceId service provides several constructors for resource ids.
    
    They mainly differ in how the anchor is specified.

    See Also:
        `API ResourceId <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1framework_1_1ResourceId.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing.framework'
    __ooo_full_ns__: str = 'com.sun.star.drawing.framework.ResourceId'
    __ooo_type_name__: str = 'service'

    @abstractmethod
    def create(self, sResourceURL: str) -> None:
        """
        Create a resource id that has no anchor.
        
        This constructor can be used to create resource ids for panes.
        """
        ...
    @abstractmethod
    def createEmpty(self) -> None:
        """
        Create an empty resource id.
        
        It does not specify a specific resource but describes the absence of one.
        """
        ...
    @abstractmethod
    def createWithAnchor(self, sResourceURL: str, xAnchor: XResourceId_5be3103d) -> None:
        """
        Create a resource id for an anchor that is given as XResourceId object.
        
        This is the most general of the constructor variants.
        """
        ...
    @abstractmethod
    def createWithAnchorURL(self, sResourceURL: str, sAnchorURL: str) -> None:
        """
        Create a resource id for a resource that is bound to an anchor that can be specified by a single URL.
        
        This constructor can be used to create resources ids for views where the anchor is a pane.
        """
        ...

__all__ = ['ResourceId']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.style
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class PageStyleLayout(metaclass=UnoEnumMeta, type_name="com.sun.star.style.PageStyleLayout", name_space="com.sun.star.style"):
        """Dynamically created class that represents ``com.sun.star.style.PageStyleLayout`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.style.PageStyleLayout import ALL as PAGE_STYLE_LAYOUT_ALL
        from com.sun.star.style.PageStyleLayout import LEFT as PAGE_STYLE_LAYOUT_LEFT
        from com.sun.star.style.PageStyleLayout import MIRRORED as PAGE_STYLE_LAYOUT_MIRRORED
        from com.sun.star.style.PageStyleLayout import RIGHT as PAGE_STYLE_LAYOUT_RIGHT

        class PageStyleLayout(uno.Enum):
            """
            Enum Class


            See Also:
                `API PageStyleLayout <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1style.html#ae13f8c21c10b194207bb33f84a33d50f>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.style.PageStyleLayout', value)

            __ooo_ns__: str = 'com.sun.star.style'
            __ooo_full_ns__: str = 'com.sun.star.style.PageStyleLayout'
            __ooo_type_name__: str = 'enum'

            ALL = PAGE_STYLE_LAYOUT_ALL
            """
            The page style is identically used for left and right pages.
            """
            LEFT = PAGE_STYLE_LAYOUT_LEFT
            """
            set the horizontal alignment to the left margin from the container object

            The text range is left-aligned between the previous tabulator (or the left border, if none) and this tabulator.

            adjusted to the left border

            The page style is only used for left pages.
            """
            MIRRORED = PAGE_STYLE_LAYOUT_MIRRORED
            """
            The page style is used unchanged for left pages and mirrored for right pages.
            """
            RIGHT = PAGE_STYLE_LAYOUT_RIGHT
            """
            set the horizontal alignment to the right margin from the container object

            The text range is right-aligned between the previous tabulator (or the left border, if none) and this tabulator.

            adjusted to the right border

            The page style is only used for right pages.
            """
    else:
        # keep document generators happy
        from ...lo.style.page_style_layout import PageStyleLayout as PageStyleLayout


__all__ = ['PageStyleLayout']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.form
# Libre Office Version: 7.4
from __future__ import annotations
from typing import cast, TYPE_CHECKING
from enum import Enum
if TYPE_CHECKING:
    from com.sun.star.form.TabulatorCycle import TabulatorCycleProto

class TabulatorCycle(Enum):
    """
    Enum Class


    See Also:
        `API TabulatorCycle <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1form.html#acb5251eb1c7e6ff2149158596346de94>`_
    """
    __ooo_ns__: str = 'com.sun.star.form'
    __ooo_full_ns__: str = 'com.sun.star.form.TabulatorCycle'
    __ooo_type_name__: str = 'enum'

    @property
    def typeName(self) -> str:
        return 'com.sun.star.form.TabulatorCycle'

    CURRENT = cast("TabulatorCycleProto", 'CURRENT')
    """
    a navigation bar is provided and navigation will be performed on the current/active form.
    
    pressing the TAB key from the last control moves the focus to the first control in the tab order of the same record.
    
    This is the default and most often encountered mode.
    """
    PAGE = cast("TabulatorCycleProto", 'PAGE')
    """
    pressing the TAB key from the last control of a form moves the focus to the first control of the next form in the tab order.
    """
    RECORDS = cast("TabulatorCycleProto", 'RECORDS')
    """
    pressing the TAB key from the last control moves the focus to the first control in the tab order of the next record.
    """

__all__ = ['TabulatorCycle']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdb
from __future__ import annotations
import typing
from abc import abstractmethod, ABC
if typing.TYPE_CHECKING:
    from .x_database_registrations_listener import XDatabaseRegistrationsListener as XDatabaseRegistrationsListener_acf11262

class XDatabaseRegistrations(ABC):
    """
    provides access to the application-wide registered databases.
    
    This interface provides a mere wrapper around the respective configuration data, this way hiding the concrete configuration structure from its clients. You should, if possible at all, use this interface, instead of modifying or querying the configuration data directly.
    
    **since**
    
        OOo 3.3

    See Also:
        `API XDatabaseRegistrations <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseRegistrations.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb'
    __ooo_full_ns__: str = 'com.sun.star.sdb.XDatabaseRegistrations'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sdb.XDatabaseRegistrations'

    @abstractmethod
    def addDatabaseRegistrationsListener(self, Listener: XDatabaseRegistrationsListener_acf11262) -> None:
        """
        registers a listener which is notified of changes in the registered databases
        """
        ...
    @abstractmethod
    def changeDatabaseLocation(self, Name: str, NewLocation: str) -> None:
        """
        changes the location of a given database registration

        Raises:
            : ````
            : ````
            com.sun.star.lang.IllegalAccessException: ``IllegalAccessException``
        """
        ...
    @abstractmethod
    def getDatabaseLocation(self, Name: str) -> str:
        """
        returns the location of the database registered under the given name

        Raises:
            : ````
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
        ...
    @abstractmethod
    def getRegistrationNames(self) -> typing.Tuple[str, ...]:
        """
        returns the names of all registered databases
        """
        ...
    @abstractmethod
    def hasRegisteredDatabase(self, Name: str) -> bool:
        """
        determines whether a database is registered under the given name.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def isDatabaseRegistrationReadOnly(self, Name: str) -> bool:
        """
        determines whether the registration data for a database given by name is read-only.
        
        In this case, attempts to revoke this registration will fail.

        Raises:
            : ````
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
        ...
    @abstractmethod
    def registerDatabaseLocation(self, Name: str, Location: str) -> None:
        """
        registers a database, given by location, under a given name

        Raises:
            : ````
            com.sun.star.container.ElementExistException: ``ElementExistException``
        """
        ...
    @abstractmethod
    def removeDatabaseRegistrationsListener(self, Listener: XDatabaseRegistrationsListener_acf11262) -> None:
        """
        revokes a previously registered listener
        """
        ...
    @abstractmethod
    def revokeDatabaseLocation(self, Name: str) -> None:
        """
        revokes the registration of a database, given by name

        Raises:
            : ````
            : ````
            com.sun.star.lang.IllegalAccessException: ``IllegalAccessException``
        """
        ...

__all__ = ['XDatabaseRegistrations']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ui.dialogs
from __future__ import annotations
from abc import abstractmethod
from .x_executable_dialog import XExecutableDialog as XExecutableDialog_450f0fa1

class XFolderPicker(XExecutableDialog_450f0fa1):
    """
    Specifies a FolderPicker interface.

    See Also:
        `API XFolderPicker <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XFolderPicker.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ui.dialogs'
    __ooo_full_ns__: str = 'com.sun.star.ui.dialogs.XFolderPicker'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.ui.dialogs.XFolderPicker'

    @abstractmethod
    def getDirectory(self) -> str:
        """
        Returns the selected directory as url conforming to Rfc1738.
        """
        ...
    @abstractmethod
    def getDisplayDirectory(self) -> str:
        """
        Returns the root directory that the FolderPicker is showing.
        
        The return value is undefined if the client did not choose a root directory or the previously specified root directory doesn't exist.
        """
        ...
    @abstractmethod
    def setDescription(self, aDescription: str) -> None:
        """
        The implementation may optionally show the given text as a description for the user within the dialog, e.g.
        
        \"Please select a directory\". If the client doesn't set a description the dialog may show a default description.
        """
        ...
    @abstractmethod
    def setDisplayDirectory(self, aDirectory: str) -> None:
        """
        Sets the root directory that the FolderPicker should display.
        
        It is not specified which root directory the FolderPicker chooses if the specified root directory doesn't exist.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['XFolderPicker']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart2
from __future__ import annotations
import typing
from abc import abstractproperty
from ..chart.x3_d_default_setter import X3DDefaultSetter as X3DDefaultSetter_e9630d25
from .x_coordinate_system_container import XCoordinateSystemContainer as XCoordinateSystemContainer_995411d4
from .x_diagram import XDiagram as XDiagram_96fe0a59
from .x_titled import XTitled as XTitled_8d490a0a
if typing.TYPE_CHECKING:
    from .relative_position import RelativePosition as RelativePosition_fae10ddd
    from .relative_size import RelativeSize as RelativeSize_c6020c23

class Diagram(X3DDefaultSetter_e9630d25, XCoordinateSystemContainer_995411d4, XDiagram_96fe0a59, XTitled_8d490a0a):
    """
    Service Class


    See Also:
        `API Diagram <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1chart2_1_1Diagram.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart2'
    __ooo_full_ns__: str = 'com.sun.star.chart2.Diagram'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def ConnectBars(self) -> bool:
        """
        Draw connection lines for stacked bar charts.
        """
        ...

    @abstractproperty
    def DataTableHBorder(self) -> bool:
        """
        Chart Datatable flags.
        """
        ...

    @abstractproperty
    def DataTableOutline(self) -> bool:
        """
        """
        ...

    @abstractproperty
    def DataTableVBorder(self) -> bool:
        """
        """
        ...

    @abstractproperty
    def ExternalData(self) -> str:
        """
        """
        ...

    @abstractproperty
    def GroupBarsPerAxis(self) -> bool:
        """
        If bars of a bar or column chart are attached to different axis, this property determines how to display those.
        
        If TRUE, the bars are grouped together in one block for each axis, thus they are painted one group over the other.
        
        If FALSE, the bars are displayed side-by-side, as if they were all attached to the same axis.
        
        If all data series of a bar or column chart are attached to only one axis, this property has no effect.
        """
        ...

    @abstractproperty
    def MissingValueTreatment(self) -> int:
        """
        specifies how empty or invalid cells in the provided data should be handled when displayed
        """
        ...

    @abstractproperty
    def Perspective(self) -> int:
        """
        Perspective of 3D charts ( [0,100] ).
        """
        ...

    @abstractproperty
    def PosSizeExcludeLabels(self) -> bool:
        """
        The attributes RelativePosition and RelativeSize should be used for the inner coordinate region without axis labels and without data labels.
        """
        ...

    @abstractproperty
    def RelativePosition(self) -> RelativePosition_fae10ddd:
        """
        The position is as a relative position on the page.
        
        If a relative position is given the diagram is not automatically placed, but instead is placed relative on the page.
        """
        ...

    @abstractproperty
    def RelativeSize(self) -> RelativeSize_c6020c23:
        """
        The size of the diagram as relative size of the page size.
        """
        ...

    @abstractproperty
    def RightAngledAxes(self) -> bool:
        """
        """
        ...

    @abstractproperty
    def RotationHorizontal(self) -> int:
        """
        Horizontal rotation of 3D charts in degrees ( ]-180,180] ).
        """
        ...

    @abstractproperty
    def RotationVertical(self) -> int:
        """
        Vertical rotation of 3D charts in degrees ( ]-180,180] ).
        """
        ...

    @abstractproperty
    def SortByXValues(self) -> bool:
        """
        Sort data points by x values for rendering.
        """
        ...

    @abstractproperty
    def StartingAngle(self) -> int:
        """
        Starting angle in degrees for pie charts and doughnut charts.
        """
        ...


__all__ = ['Diagram']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
from __future__ import annotations
import typing
from abc import abstractproperty
from .x_text_columns import XTextColumns as XTextColumns_b17f0bab
if typing.TYPE_CHECKING:
    from ..util.color import Color as Color_68e908c5
    from com.sun.star.style.VerticalAlignment import VerticalAlignmentProto

class TextColumns(XTextColumns_b17f0bab):
    """
    Service Class

    provides access to columns in text (e.g., in TextFrames ).

    See Also:
        `API TextColumns <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1TextColumns.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.TextColumns'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def AutomaticDistance(self) -> int:
        """
        contains the distance between the columns.
        
        It is valid if the property IsAutomatic is set. Half of this distance is set to the left and right margins of all columns, except for the left margin of the first column, and the right margin of the last column.
        """
        ...

    @abstractproperty
    def IsAutomatic(self) -> bool:
        """
        determines whether the columns all have equal width.
        
        This flag is set if XTextColumns.setColumnCount() is called and it is reset if XTextColumns.setColumns() is called.
        """
        ...

    @abstractproperty
    def SeparatorLineColor(self) -> Color_68e908c5:
        """
        determines the color of the separator lines between the columns.
        """
        ...

    @abstractproperty
    def SeparatorLineIsOn(self) -> bool:
        """
        determines whether separator lines are on.
        """
        ...

    @abstractproperty
    def SeparatorLineRelativeHeight(self) -> int:
        """
        determines the relative height of the separator lines between the columns.
        """
        ...

    @abstractproperty
    def SeparatorLineStyle(self) -> int:
        """
        determines the style of the separator lines between the columns.
        """
        ...

    @abstractproperty
    def SeparatorLineVerticalAlignment(self) -> VerticalAlignmentProto:
        """
        determines the vertical alignment of the separator lines between the columns.
        """
        ...

    @abstractproperty
    def SeparatorLineWidth(self) -> int:
        """
        determines the width of the separator lines between the columns.
        """
        ...


__all__ = ['TextColumns']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.inspection
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_object_inspector import XObjectInspector as XObjectInspector_3c860faa
if typing.TYPE_CHECKING:
    from .x_object_inspector_model import XObjectInspectorModel as XObjectInspectorModel_9077119b

class ObjectInspector(XObjectInspector_3c860faa):
    """
    Service Class

    describes a com.sun.star.frame.Controller which can be used to browse and modify properties of components.
    
    The controller can be plugged into a com.sun.star.frame.XFrame, and will provide a visual component for inspecting and modifying component properties.Note that \"property\" here is a generic term - any aspect of a component can be considered a property, as long as some property handler is able to describe this aspect in a property-like way.
    
    The basic idea is that one facet of the inspected component is represented by a single line of controls: A label, an input control, and optionally one or two buttons which, when pressed, trigger additional user interaction (e.g. a more sophisticated dialog to enter a property value).
    
    Additionally, property lines can be grouped into different categories. A usual implementation of such categories would be tab pages, but other implementations are possible, too.
    
    Even more, the inspector can optionally display a help section at the bottom of its window, which can display arbitrary (context-sensitive) help texts.
    
    An ObjectInspector needs one or more property handlers which describe the facets of an inspected component - without such handlers, the inspector window will simply stay empty.
    
    The property handlers, as well as more information about the layout of the inspector, are provided by an inspector model, which has to be implemented by the user of the inspector.
    
    Since property handlers might have the need to raise UI, they will be created with a context value named \"DialogParentWindow\", which contains an XWindow which should be used as parent of any windows to raise.If the com.sun.star.uno.XComponentContext in which the ObjectInspector was created already contains such a value, it is not overwritten. Only if it doesn't, the inspector will add an own value - which contains the inspector's main window - to the context when creating handlers.
    
    **since**
    
        OOo 2.0.3

    See Also:
        `API ObjectInspector <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1inspection_1_1ObjectInspector.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.inspection'
    __ooo_full_ns__: str = 'com.sun.star.inspection.ObjectInspector'
    __ooo_type_name__: str = 'service'

    @abstractmethod
    def createDefault(self) -> None:
        """
        creates a default instance of the ObjectInspector
        
        **since**
        
            OOo 2.2
        """
        ...
    @abstractmethod
    def createWithModel(self, Model: XObjectInspectorModel_9077119b) -> None:
        """
        creates an instance of the ObjectInspector, using a given ObjectInspectorModel
        
        **since**
        
            OOo 2.2

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['ObjectInspector']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ..uno.exception import Exception as Exception_85530a09
from ..uno.x_interface import XInterface as XInterface_8f010a43

class CommandFailedException(Exception_85530a09):
    """
    Exception Class

    This exception is thrown if an exception situation occurred during the processing of a command and an com.sun.star.task.XInteractionHandler was able to handle the request for the error condition and the requesting code decided to abort the command execution according to the selection made by the interaction handler.

    See Also:
        `API CommandFailedException <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1ucb_1_1CommandFailedException.html>`_
    """

    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.CommandFailedException'
    __ooo_type_name__: str = 'exception'
    __pyunointerface__: str = 'com.sun.star.ucb.CommandFailedException'
    __pyunostruct__: str = 'com.sun.star.ucb.CommandFailedException'

    typeName: str = 'com.sun.star.ucb.CommandFailedException'
    """Literal Constant ``com.sun.star.ucb.CommandFailedException``"""

    def __init__(self, Message: typing.Optional[str] = '', Context: typing.Optional[XInterface_8f010a43] = None, Reason: typing.Optional[object] = None) -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
            Reason (object, optional): Reason value.
        """
        kargs = {
            "Message": Message,
            "Context": Context,
            "Reason": Reason,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._reason = kwargs["Reason"]
        inst_keys = ('Reason',)
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)

    @property
    def Reason(self) -> object:
        """
        contains the exception that was passed to the com.sun.star.task.XInteractionHandler.
        """
        return self._reason
    
    @Reason.setter
    def Reason(self, value: object) -> None:
        self._reason = value


__all__ = ['CommandFailedException']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.4
from __future__ import annotations
from typing import cast, TYPE_CHECKING
from enum import Enum
if TYPE_CHECKING:
    from com.sun.star.ucb.ContentCreationError import ContentCreationErrorProto

class ContentCreationError(Enum):
    """
    Enum Class


    See Also:
        `API ContentCreationError <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1ucb.html#aa2e437022c4d519cf5488a06e5e81ef4>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.ContentCreationError'
    __ooo_type_name__: str = 'enum'

    @property
    def typeName(self) -> str:
        return 'com.sun.star.ucb.ContentCreationError'

    CONTENT_CREATION_FAILED = cast("ContentCreationErrorProto", 'CONTENT_CREATION_FAILED')
    """
    Provider was unable to create the content instance.
    """
    IDENTIFIER_CREATION_FAILED = cast("ContentCreationErrorProto", 'IDENTIFIER_CREATION_FAILED')
    """
    Creation of content identifier failed.
    """
    NO_CONTENT_BROKER = cast("ContentCreationErrorProto", 'NO_CONTENT_BROKER')
    """
    """
    NO_CONTENT_PROVIDER = cast("ContentCreationErrorProto", 'NO_CONTENT_PROVIDER')
    """
    No Content Provider for given content identifier available.
    """
    NO_IDENTIFIER_FACTORY = cast("ContentCreationErrorProto", 'NO_IDENTIFIER_FACTORY')
    """
    """
    UNKNOWN = cast("ContentCreationErrorProto", 'UNKNOWN')
    """
    Unknown.
    
    An unknown I/O error has occurred.
    """

__all__ = ['ContentCreationError']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_printer_property_set import XPrinterPropertySet as XPrinterPropertySet_ff190e21
if typing.TYPE_CHECKING:
    from .x_device import XDevice as XDevice_70ba08fc

class XPrinter(XPrinterPropertySet_ff190e21):
    """
    represents a virtual printer.
    
    All properties are vetoable properties. If you change the properties between a call to com.sun.star.awt.XPrinter.startPage() and a call to com.sun.star.awt.XPrinter.endPage(), a com.sun.star.beans.PropertyVetoException is thrown.

    See Also:
        `API XPrinter <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XPrinter.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XPrinter'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XPrinter'

    @abstractmethod
    def end(self) -> None:
        """
        notifies the printer spooler that the job is done and printing starts.

        Raises:
            com.sun.star.awt.PrinterException: ``PrinterException``
        """
        ...
    @abstractmethod
    def endPage(self) -> None:
        """
        ends the current page.

        Raises:
            com.sun.star.awt.PrinterException: ``PrinterException``
        """
        ...
    @abstractmethod
    def start(self, nJobName: str, nCopies: int, nCollate: bool) -> bool:
        """
        puts the job into the printer spooler.
        
        This call may block the thread. So release all resources (mutex, semaphore, etc.) before this call.

        Raises:
            com.sun.star.awt.PrinterException: ``PrinterException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def startPage(self) -> XDevice_70ba08fc:
        """
        begins with a new page.

        Raises:
            com.sun.star.awt.PrinterException: ``PrinterException``
        """
        ...
    @abstractmethod
    def terminate(self) -> None:
        """
        stops the current print job.
        
        If the method com.sun.star.awt.XPrinter.end() is called beforehand, then this call does nothing. If you call com.sun.star.awt.XPrinter.terminate() in or before the call to com.sun.star.awt.XPrinter.start(), com.sun.star.awt.XPrinter.terminate() returns FALSE. This call must not block the thread.
        """
        ...

__all__ = ['XPrinter']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.xml.crypto
# Libre Office Version: 7.4
from __future__ import annotations
from typing import cast, TYPE_CHECKING
from enum import Enum
if TYPE_CHECKING:
    from com.sun.star.xml.crypto.SecurityOperationStatus import SecurityOperationStatusProto

class SecurityOperationStatus(Enum):
    """
    Enum Class


    See Also:
        `API SecurityOperationStatus <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1xml_1_1crypto.html#ab5d887eb5da1173b766d96d0d863d1dc>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.crypto'
    __ooo_full_ns__: str = 'com.sun.star.xml.crypto.SecurityOperationStatus'
    __ooo_type_name__: str = 'enum'

    @property
    def typeName(self) -> str:
        return 'com.sun.star.xml.crypto.SecurityOperationStatus'

    ASSERTION = cast("SecurityOperationStatusProto", 'ASSERTION')
    """
    """
    CERT_HAS_EXPIRED = cast("SecurityOperationStatusProto", 'CERT_HAS_EXPIRED')
    """
    """
    CERT_ISSUER_FAILED = cast("SecurityOperationStatusProto", 'CERT_ISSUER_FAILED')
    """
    """
    CERT_NOT_FOUND = cast("SecurityOperationStatusProto", 'CERT_NOT_FOUND')
    """
    """
    CERT_NOT_YET_VALID = cast("SecurityOperationStatusProto", 'CERT_NOT_YET_VALID')
    """
    """
    CERT_REVOKED = cast("SecurityOperationStatusProto", 'CERT_REVOKED')
    """
    """
    CERT_VERIFY_FAILED = cast("SecurityOperationStatusProto", 'CERT_VERIFY_FAILED')
    """
    """
    CRYPTO_FAILED = cast("SecurityOperationStatusProto", 'CRYPTO_FAILED')
    """
    """
    DATA_NOT_MATCH = cast("SecurityOperationStatusProto", 'DATA_NOT_MATCH')
    """
    """
    DISABLED = cast("SecurityOperationStatusProto", 'DISABLED')
    """
    """
    DSIG_INVALID_REFERENCE = cast("SecurityOperationStatusProto", 'DSIG_INVALID_REFERENCE')
    """
    """
    DSIG_NO_REFERENCES = cast("SecurityOperationStatusProto", 'DSIG_NO_REFERENCES')
    """
    """
    ENGINE_FAILED = cast("SecurityOperationStatusProto", 'ENGINE_FAILED')
    """
    The following constants are derived from XMLSec error definitions, as following:
    
    XMLSEC_ERRORS_R_XMLSEC_FAILED XMLSEC_ERRORS_R_MALLOC_FAILED XMLSEC_ERRORS_R_STRDUP_FAILED XMLSEC_ERRORS_R_CRYPTO_FAILED XMLSEC_ERRORS_R_XML_FAILED XMLSEC_ERRORS_R_XSLT_FAILED XMLSEC_ERRORS_R_IO_FAILED XMLSEC_ERRORS_R_DISABLED XMLSEC_ERRORS_R_NOT_IMPLEMENTED XMLSEC_ERRORS_R_INVALID_SIZE XMLSEC_ERRORS_R_INVALID_DATA XMLSEC_ERRORS_R_INVALID_RESULT XMLSEC_ERRORS_R_INVALID_TYPE XMLSEC_ERRORS_R_INVALID_OPERATION XMLSEC_ERRORS_R_INVALID_STATUS XMLSEC_ERRORS_R_INVALID_FORMAT XMLSEC_ERRORS_R_DATA_NOT_MATCH XMLSEC_ERRORS_R_INVALID_NODE XMLSEC_ERRORS_R_INVALID_NODE_CONTENT XMLSEC_ERRORS_R_INVALID_NODE_ATTRIBUTE XMLSEC_ERRORS_R_MISSING_NODE_ATTRIBUTE XMLSEC_ERRORS_R_NODE_ALREADY_PRESENT XMLSEC_ERRORS_R_UNEXPECTED_NODE XMLSEC_ERRORS_R_NODE_NOT_FOUND XMLSEC_ERRORS_R_INVALID_TRANSFORM XMLSEC_ERRORS_R_INVALID_TRANSFORM_KEY XMLSEC_ERRORS_R_INVALID_URI_TYPE XMLSEC_ERRORS_R_TRANSFORM_SAME_DOCUMENT_REQUIRED XMLSEC_ERRORS_R_TRANSFORM_DISABLED XMLSEC_ERRORS_R_INVALID_KEY_DATA XMLSEC_ERRORS_R_KEY_DATA_NOT_FOUND XMLSEC_ERRORS_R_KEY_DATA_ALREADY_EXIST XMLSEC_ERRORS_R_INVALID_KEY_DATA_SIZE XMLSEC_ERRORS_R_KEY_NOT_FOUND XMLSEC_ERRORS_R_KEYDATA_DISABLED XMLSEC_ERRORS_R_MAX_RETRIEVALS_LEVEL XMLSEC_ERRORS_R_MAX_RETRIEVAL_TYPE_MISMATCH XMLSEC_ERRORS_R_MAX_ENCKEY_LEVEL XMLSEC_ERRORS_R_CERT_VERIFY_FAILED XMLSEC_ERRORS_R_CERT_NOT_FOUND XMLSEC_ERRORS_R_CERT_REVOKED XMLSEC_ERRORS_R_CERT_ISSUER_FAILED XMLSEC_ERRORS_R_CERT_NOT_YET_VALID XMLSEC_ERRORS_R_CERT_HAS_EXPIRED XMLSEC_ERRORS_R_DSIG_NO_REFERENCES XMLSEC_ERRORS_R_DSIG_INVALID_REFERENCE XMLSEC_ERRORS_R_ASSERTION XMLSEC_ERRORS_MAX_NUMBER
    """
    INVALID_DATA = cast("SecurityOperationStatusProto", 'INVALID_DATA')
    """
    """
    INVALID_FORMAT = cast("SecurityOperationStatusProto", 'INVALID_FORMAT')
    """
    """
    INVALID_KEY_DATA = cast("SecurityOperationStatusProto", 'INVALID_KEY_DATA')
    """
    """
    INVALID_KEY_DATA_SIZE = cast("SecurityOperationStatusProto", 'INVALID_KEY_DATA_SIZE')
    """
    """
    INVALID_NODE = cast("SecurityOperationStatusProto", 'INVALID_NODE')
    """
    """
    INVALID_NODE_ATTRIBUTE = cast("SecurityOperationStatusProto", 'INVALID_NODE_ATTRIBUTE')
    """
    """
    INVALID_NODE_CONTENT = cast("SecurityOperationStatusProto", 'INVALID_NODE_CONTENT')
    """
    """
    INVALID_OPERATION = cast("SecurityOperationStatusProto", 'INVALID_OPERATION')
    """
    """
    INVALID_RESULT = cast("SecurityOperationStatusProto", 'INVALID_RESULT')
    """
    """
    INVALID_SIZE = cast("SecurityOperationStatusProto", 'INVALID_SIZE')
    """
    """
    INVALID_STATUS = cast("SecurityOperationStatusProto", 'INVALID_STATUS')
    """
    """
    INVALID_TRANSFORM = cast("SecurityOperationStatusProto", 'INVALID_TRANSFORM')
    """
    """
    INVALID_TRANSFORM_KEY = cast("SecurityOperationStatusProto", 'INVALID_TRANSFORM_KEY')
    """
    """
    INVALID_TYPE = cast("SecurityOperationStatusProto", 'INVALID_TYPE')
    """
    """
    INVALID_URI_TYPE = cast("SecurityOperationStatusProto", 'INVALID_URI_TYPE')
    """
    """
    IO_FAILED = cast("SecurityOperationStatusProto", 'IO_FAILED')
    """
    """
    KEYDATA_DISABLED = cast("SecurityOperationStatusProto", 'KEYDATA_DISABLED')
    """
    """
    KEY_DATA_ALREADY_EXIST = cast("SecurityOperationStatusProto", 'KEY_DATA_ALREADY_EXIST')
    """
    """
    KEY_DATA_NOT_FOUND = cast("SecurityOperationStatusProto", 'KEY_DATA_NOT_FOUND')
    """
    """
    KEY_NOT_FOUND = cast("SecurityOperationStatusProto", 'KEY_NOT_FOUND')
    """
    """
    MALLOC_FAILED = cast("SecurityOperationStatusProto", 'MALLOC_FAILED')
    """
    """
    MAX_ENCKEY_LEVEL = cast("SecurityOperationStatusProto", 'MAX_ENCKEY_LEVEL')
    """
    """
    MAX_RETRIEVALS_LEVEL = cast("SecurityOperationStatusProto", 'MAX_RETRIEVALS_LEVEL')
    """
    """
    MAX_RETRIEVAL_TYPE_MISMATCH = cast("SecurityOperationStatusProto", 'MAX_RETRIEVAL_TYPE_MISMATCH')
    """
    """
    MISSING_NODE_ATTRIBUTE = cast("SecurityOperationStatusProto", 'MISSING_NODE_ATTRIBUTE')
    """
    """
    NODE_ALREADY_PRESENT = cast("SecurityOperationStatusProto", 'NODE_ALREADY_PRESENT')
    """
    """
    NODE_NOT_FOUND = cast("SecurityOperationStatusProto", 'NODE_NOT_FOUND')
    """
    """
    NOT_IMPLEMENTED = cast("SecurityOperationStatusProto", 'NOT_IMPLEMENTED')
    """
    """
    OPERATION_SUCCEEDED = cast("SecurityOperationStatusProto", 'OPERATION_SUCCEEDED')
    """
    """
    RUNTIMEERROR_FAILED = cast("SecurityOperationStatusProto", 'RUNTIMEERROR_FAILED')
    """
    """
    STRDUP_FAILED = cast("SecurityOperationStatusProto", 'STRDUP_FAILED')
    """
    """
    TRANSFORM_DISABLED = cast("SecurityOperationStatusProto", 'TRANSFORM_DISABLED')
    """
    """
    TRANSFORM_SAME_DOCUMENT_REQUIRED = cast("SecurityOperationStatusProto", 'TRANSFORM_SAME_DOCUMENT_REQUIRED')
    """
    """
    UNEXPECTED_NODE = cast("SecurityOperationStatusProto", 'UNEXPECTED_NODE')
    """
    """
    UNKNOWN = cast("SecurityOperationStatusProto", 'UNKNOWN')
    """
    """
    XML_FAILED = cast("SecurityOperationStatusProto", 'XML_FAILED')
    """
    """
    XSLT_FAILED = cast("SecurityOperationStatusProto", 'XSLT_FAILED')
    """
    """

__all__ = ['SecurityOperationStatus']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.rendering
from __future__ import annotations
import typing
import uno
from abc import abstractmethod
from .x_color_space import XColorSpace as XColorSpace_e3940d09
if typing.TYPE_CHECKING:
    from .argb_color import ARGBColor as ARGBColor_c6ee0be1
    from .color_component import ColorComponent as ColorComponent_e4c0e78
    from .rgb_color import RGBColor as RGBColor_bbdf0ba0

class XIntegerBitmapColorSpace(XColorSpace_e3940d09):
    """
    A color space for integer bitmap formats.
    
    This interface encapsulates all information specific to a certain integer bitmap color space, like for example 1555 ARGB. Note that the individual elements of the integer color representation sequence need not correspond to the color space's components - instead, the color components might be packed back-to-back into those bytes, as they appear in the raw bitmap data.

    See Also:
        `API XIntegerBitmapColorSpace <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1rendering_1_1XIntegerBitmapColorSpace.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.rendering'
    __ooo_full_ns__: str = 'com.sun.star.rendering.XIntegerBitmapColorSpace'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.rendering.XIntegerBitmapColorSpace'

    @abstractmethod
    def convertFromIntegerColorSpace(self, deviceColor: uno.ByteSequence, targetColorSpace: XColorSpace_e3940d09) -> typing.Tuple[ColorComponent_e4c0e78, ...]:
        """
        Convert integer bitmap color to generic IEEE double device color of another color space.
        
        Color values are properly rounded and clipped, to be valid in the target color space.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def convertIntegerFromARGB(self, rgbColor: typing.Tuple[ARGBColor_c6ee0be1, ...]) -> uno.ByteSequence:
        """
        Convert sRGB color with linear alpha into this color space.
        
        If this color space does not convey alpha information, the specified alpha value is silently ignored. Color values are properly rounded and clipped, to be valid in the target color space.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def convertIntegerFromPARGB(self, rgbColor: typing.Tuple[ARGBColor_c6ee0be1, ...]) -> uno.ByteSequence:
        """
        Convert premultiplied sRGB color with linear alpha into this color space.
        
        If this color space does not convey alpha information, the specified alpha value is silently ignored. Color values are properly rounded and clipped, to be valid in the target color space.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def convertIntegerFromRGB(self, rgbColor: typing.Tuple[RGBColor_bbdf0ba0, ...]) -> uno.ByteSequence:
        """
        Convert sRGB color to an integer representation in this color space.
        
        If this color space conveys alpha information, it is assumed be fully opaque for the given RGB color value. Color values are properly rounded and clipped, to be valid in the target color space.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def convertIntegerToARGB(self, deviceColor: uno.ByteSequence) -> typing.Tuple[ARGBColor_c6ee0be1, ...]:
        """
        Convert color value in this color space to sRGB color values, with linear alpha.
        
        If the given input color does not carry alpha information, an alpha value of 1.0 (fully opaque) is assumed. Color values are properly rounded and clipped, to be valid in the target color space.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def convertIntegerToPARGB(self, deviceColor: uno.ByteSequence) -> typing.Tuple[ARGBColor_c6ee0be1, ...]:
        """
        Convert color value in this color space to premultiplied sRGB color values, with linear alpha.
        
        If the given input color does not carry alpha information, an alpha value of 1.0 (fully opaque) is assumed. Color values are properly rounded and clipped, to be valid in the target color space. The resulting individual RGB color values are premultiplied by the alpha value (e.g. if alpha is 0.5, each color value has only half of the original intensity).

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def convertIntegerToRGB(self, deviceColor: uno.ByteSequence) -> typing.Tuple[RGBColor_bbdf0ba0, ...]:
        """
        Convert color value in this color space to sRGB color values.
        
        Any information not representable in the RGBColor struct is discarded during the conversion. This includes alpha information. Color values are properly rounded and clipped, to be valid in the target color space.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def convertToIntegerColorSpace(self, deviceColor: uno.ByteSequence, targetColorSpace: XIntegerBitmapColorSpace) -> uno.ByteSequence:
        """
        Convert integer bitmap color to integer bitmap color of another integer bitmap color space.
        
        Color values are properly rounded and clipped, to be valid in the target color space.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def getBitsPerPixel(self) -> int:
        """
        Query number of bits used per bitmap pixel.
        
        This method yields the total number of bits used for a color value. At the associated XIntegerBitmap, the XIntegerBitmap.setPixel() method will expect a sequence of ceil(BitsPerPixel/8) bytes, and the XIntegerReadOnlyBitmap.getPixel() will return that number of bytes. Similarly, the color conversion expect input data in multiples of ceil(BitsPerPixel/8), and also return converted data in chunks of this.
        """
        ...
    @abstractmethod
    def getComponentBitCounts(self) -> uno.ByteSequence:
        """
        Query the number of bits used for each component.
        
        This method returns a sequence of integers, each denoting the number of bits occupied by the respective component. The sum of all component bits must be less or equal than the value returned from getBitsPerPixel(). If the sum is less, excess bits are always kept in the most significant bits of a pixel. Color components will appear in the byte sequences returned from the XIntegerBitmap methods in the order defined here, with the first element starting from the least significant bits of the pixel, etc.
        """
        ...
    @abstractmethod
    def getEndianness(self) -> int:
        """
        Query whether color data bytes need to be swapped.
        """
        ...

__all__ = ['XIntegerBitmapColorSpace']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_image_consumer import XImageConsumer as XImageConsumer_ba790bdb

class XImageProducer(XInterface_8f010a43):
    """
    specifies a source for an image.

    See Also:
        `API XImageProducer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XImageProducer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XImageProducer'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XImageProducer'

    @abstractmethod
    def addConsumer(self, xConsumer: XImageConsumer_ba790bdb) -> None:
        """
        registers an image consumer with the image producer for accessing the image data during a later reconstruction of the image.
        
        The image producer may, at its discretion, start delivering the image data to the consumer using the XImageConsumer interface immediately, or when the next available image reconstruction is triggered by a call to the startProduction method.
        """
        ...
    @abstractmethod
    def removeConsumer(self, xConsumer: XImageConsumer_ba790bdb) -> None:
        """
        removes the given com.sun.star.awt.XImageConsumer callback from the list of consumers currently registered to receive image data.
        
        It is not considered an error to remove a consumer that is not currently registered. The image producer should stop sending data to this consumer as soon as it is feasible.
        """
        ...
    @abstractmethod
    def startProduction(self) -> None:
        """
        registers the given image consumer as a consumer and starts an immediate reconstruction of the image data.
        
        The image data will then be delivered to this consumer and any other consumer which may have already been registered with the producer. This method differs from the addConsumer method in that a reproduction of the image data should be triggered as soon as possible.
        """
        ...

__all__ = ['XImageProducer']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.frame
from __future__ import annotations
from .x_dispatch_recorder import XDispatchRecorder as XDispatchRecorder_fbd70dd1

class DispatchRecorder(XDispatchRecorder_fbd70dd1):
    """
    Service Class

    provides functionality to record XDispatch.dispatch() requests
    
    It records all necessary parameters of a call XDispatch.dispatch() and generate code which can be executed at later time to run same operations again. Which code will be generated depends from real implementation. So it's possible to generate e.g. Java/Basic or may Perl code. By using of a DispatchRecorderSupplier, which is available on a property of a Frame.DispatchRecorderSupplier, it's possible to change such code generation for further requests or disable it in general by setting this property to NULL.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API DispatchRecorder <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1frame_1_1DispatchRecorder.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame'
    __ooo_full_ns__: str = 'com.sun.star.frame.DispatchRecorder'
    __ooo_type_name__: str = 'service'


__all__ = ['DispatchRecorder']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ..task.classified_interaction_request import ClassifiedInteractionRequest as ClassifiedInteractionRequest_9f72121b
from ..uno.x_interface import XInterface as XInterface_8f010a43
from ..task.interaction_classification import InteractionClassification as InteractionClassification_6c4d10e7

class AuthenticationRequest(ClassifiedInteractionRequest_9f72121b):
    """
    Exception Class

    An error specifying lack of correct authentication data (e.g., to log into an account).

    See Also:
        `API AuthenticationRequest <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1ucb_1_1AuthenticationRequest.html>`_
    """

    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.AuthenticationRequest'
    __ooo_type_name__: str = 'exception'
    __pyunointerface__: str = 'com.sun.star.ucb.AuthenticationRequest'
    __pyunostruct__: str = 'com.sun.star.ucb.AuthenticationRequest'

    typeName: str = 'com.sun.star.ucb.AuthenticationRequest'
    """Literal Constant ``com.sun.star.ucb.AuthenticationRequest``"""

    def __init__(self, Message: typing.Optional[str] = '', Context: typing.Optional[XInterface_8f010a43] = None, Classification: typing.Optional[InteractionClassification_6c4d10e7] = InteractionClassification_6c4d10e7.ERROR, ServerName: typing.Optional[str] = '', Diagnostic: typing.Optional[str] = '', HasRealm: typing.Optional[bool] = False, Realm: typing.Optional[str] = '', HasUserName: typing.Optional[bool] = False, UserName: typing.Optional[str] = '', HasPassword: typing.Optional[bool] = False, Password: typing.Optional[str] = '', HasAccount: typing.Optional[bool] = False, Account: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
            Classification (InteractionClassification, optional): Classification value.
            ServerName (str, optional): ServerName value.
            Diagnostic (str, optional): Diagnostic value.
            HasRealm (bool, optional): HasRealm value.
            Realm (str, optional): Realm value.
            HasUserName (bool, optional): HasUserName value.
            UserName (str, optional): UserName value.
            HasPassword (bool, optional): HasPassword value.
            Password (str, optional): Password value.
            HasAccount (bool, optional): HasAccount value.
            Account (str, optional): Account value.
        """
        kargs = {
            "Message": Message,
            "Context": Context,
            "Classification": Classification,
            "ServerName": ServerName,
            "Diagnostic": Diagnostic,
            "HasRealm": HasRealm,
            "Realm": Realm,
            "HasUserName": HasUserName,
            "UserName": UserName,
            "HasPassword": HasPassword,
            "Password": Password,
            "HasAccount": HasAccount,
            "Account": Account,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._server_name = kwargs["ServerName"]
        self._diagnostic = kwargs["Diagnostic"]
        self._has_realm = kwargs["HasRealm"]
        self._realm = kwargs["Realm"]
        self._has_user_name = kwargs["HasUserName"]
        self._user_name = kwargs["UserName"]
        self._has_password = kwargs["HasPassword"]
        self._password = kwargs["Password"]
        self._has_account = kwargs["HasAccount"]
        self._account = kwargs["Account"]
        inst_keys = ('ServerName', 'Diagnostic', 'HasRealm', 'Realm', 'HasUserName', 'UserName', 'HasPassword', 'Password', 'HasAccount', 'Account')
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)

    @property
    def ServerName(self) -> str:
        """
        The name of the server (if applicable).
        """
        return self._server_name
    
    @ServerName.setter
    def ServerName(self, value: str) -> None:
        self._server_name = value

    @property
    def Diagnostic(self) -> str:
        """
        Any diagnostic message about the failure to log in (if applicable; it will typically be an English phrase or sentence).
        """
        return self._diagnostic
    
    @Diagnostic.setter
    def Diagnostic(self, value: str) -> None:
        self._diagnostic = value

    @property
    def HasRealm(self) -> bool:
        """
        Specifies if the authentication involves a \"realm\" (as can be the case for HTTP).
        """
        return self._has_realm
    
    @HasRealm.setter
    def HasRealm(self, value: bool) -> None:
        self._has_realm = value

    @property
    def Realm(self) -> str:
        """
        Any already specified realm.
        
        If HasRealm is false, this member should be ignored.
        """
        return self._realm
    
    @Realm.setter
    def Realm(self, value: str) -> None:
        self._realm = value

    @property
    def HasUserName(self) -> bool:
        """
        Specifies if the authentication involves a \"user name\" (as is almost always the case).
        """
        return self._has_user_name
    
    @HasUserName.setter
    def HasUserName(self, value: bool) -> None:
        self._has_user_name = value

    @property
    def UserName(self) -> str:
        """
        Any already specified user name.
        
        If HasUserName is false, this member should be ignored.
        """
        return self._user_name
    
    @UserName.setter
    def UserName(self, value: str) -> None:
        self._user_name = value

    @property
    def HasPassword(self) -> bool:
        """
        Specifies if the authentication involves a \"password\" (as is almost always the case).
        """
        return self._has_password
    
    @HasPassword.setter
    def HasPassword(self, value: bool) -> None:
        self._has_password = value

    @property
    def Password(self) -> str:
        """
        Any already specified password.
        
        If HasPassword is false, this member should be ignored.
        """
        return self._password
    
    @Password.setter
    def Password(self, value: str) -> None:
        self._password = value

    @property
    def HasAccount(self) -> bool:
        """
        Specifies if the authentication involves an \"account\" (as can be the case for FTP).
        """
        return self._has_account
    
    @HasAccount.setter
    def HasAccount(self, value: bool) -> None:
        self._has_account = value

    @property
    def Account(self) -> str:
        """
        Any already specified account.
        
        If HasAccount is false, this member should be ignored.
        """
        return self._account
    
    @Account.setter
    def Account(self, value: str) -> None:
        self._account = value


__all__ = ['AuthenticationRequest']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ucb
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_command_environment import XCommandEnvironment as XCommandEnvironment_fb330dee
if typing.TYPE_CHECKING:
    from ..beans.string_pair import StringPair as StringPair_a4bc0b14
    from com.sun.star.ucb.WebDAVHTTPMethod import WebDAVHTTPMethodProto

class XWebDAVCommandEnvironment(XCommandEnvironment_fb330dee):
    """
    A command environment that can be used to deal with WebDAV/HTTP specific commands.

    See Also:
        `API XWebDAVCommandEnvironment <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ucb_1_1XWebDAVCommandEnvironment.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.XWebDAVCommandEnvironment'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.ucb.XWebDAVCommandEnvironment'

    @abstractmethod
    def getUserRequestHeaders(self, aURI: str, eMethod: WebDAVHTTPMethodProto) -> typing.Tuple[StringPair_a4bc0b14, ...]:
        """
        This method gets called while assembling a WebDAV/HTTP request.
        
        The returned headername-headervalue pairs will be appended to the list of request headers before the request is dispatched.
        """
        ...

__all__ = ['XWebDAVCommandEnvironment']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.xml.crypto
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ...mozilla.mozilla_product_type import MozillaProductType as MozillaProductType_2e210f5b


class NSSProfile(object):
    """
    Struct Class

    
    **since**
    
        LibreOffice 7.1

    See Also:
        `API NSSProfile <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1xml_1_1crypto_1_1NSSProfile.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.crypto'
    __ooo_full_ns__: str = 'com.sun.star.xml.crypto.NSSProfile'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.xml.crypto.NSSProfile'
    """Literal Constant ``com.sun.star.xml.crypto.NSSProfile``"""

    def __init__(self, Name: typing.Optional[str] = '', Path: typing.Optional[str] = '', Type: typing.Optional[MozillaProductType_2e210f5b] = MozillaProductType_2e210f5b.Default) -> None:
        """
        Constructor

        Arguments:
            Name (str, optional): Name value.
            Path (str, optional): Path value.
            Type (MozillaProductType, optional): Type value.
        """
        super().__init__()

        if isinstance(Name, NSSProfile):
            oth: NSSProfile = Name
            self.Name = oth.Name
            self.Path = oth.Path
            self.Type = oth.Type
            return

        kargs = {
            "Name": Name,
            "Path": Path,
            "Type": Type,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._name = kwargs["Name"]
        self._path = kwargs["Path"]
        self._type = kwargs["Type"]


    @property
    def Name(self) -> str:
        """
        the name of the NSS profile
        
        Normally the name will reflect the name of the Mozilla profile. But the profile list also contains the following special entries: MANUAL and MOZILLA_CERTIFICATE_FOLDER. These will have a product type of MozillaProductType.Default and might have an empty path, if that value is not available.
        """
        return self._name

    @Name.setter
    def Name(self, value: str) -> None:
        self._name = value

    @property
    def Path(self) -> str:
        """
        the path to the NSS databases
        """
        return self._path

    @Path.setter
    def Path(self, value: str) -> None:
        self._path = value

    @property
    def Type(self) -> MozillaProductType_2e210f5b:
        """
        the type of the NSS profile
        """
        return self._type

    @Type.setter
    def Type(self, value: MozillaProductType_2e210f5b) -> None:
        self._type = value


__all__ = ['NSSProfile']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from contextlib import suppress
import warnings
warnings.filterwarnings('module')
warnings.warn('The cssdyn namespace is deprecated. Use dyn instead.', DeprecationWarning, stacklevel=2)

with suppress(ImportError):
    from ...dyn.view.document_zoom_type import DocumentZoomType as DocumentZoomType
with suppress(ImportError):
    from ...dyn.view.document_zoom_type import DocumentZoomTypeEnum as DocumentZoomTypeEnum
with suppress(ImportError):
    from ...dyn.view.duplex_mode import DuplexMode as DuplexMode
with suppress(ImportError):
    from ...dyn.view.duplex_mode import DuplexModeEnum as DuplexModeEnum
with suppress(ImportError):
    from ...dyn.view.office_document_view import OfficeDocumentView as OfficeDocumentView
with suppress(ImportError):
    from ...dyn.view.paper_format import PaperFormat as PaperFormat
with suppress(ImportError):
    from ...dyn.view.paper_orientation import PaperOrientation as PaperOrientation
with suppress(ImportError):
    from ...dyn.view.print_job_event import PrintJobEvent as PrintJobEvent
with suppress(ImportError):
    from ...dyn.view.print_options import PrintOptions as PrintOptions
with suppress(ImportError):
    from ...dyn.view.print_settings import PrintSettings as PrintSettings
with suppress(ImportError):
    from ...dyn.view.printable_state import PrintableState as PrintableState
with suppress(ImportError):
    from ...dyn.view.printable_state_event import PrintableStateEvent as PrintableStateEvent
with suppress(ImportError):
    from ...dyn.view.printer_descriptor import PrinterDescriptor as PrinterDescriptor
with suppress(ImportError):
    from ...dyn.view.render_descriptor import RenderDescriptor as RenderDescriptor
with suppress(ImportError):
    from ...dyn.view.render_options import RenderOptions as RenderOptions
with suppress(ImportError):
    from ...dyn.view.selection_type import SelectionType as SelectionType
with suppress(ImportError):
    from ...dyn.view.view_settings import ViewSettings as ViewSettings
with suppress(ImportError):
    from ...dyn.view.x_control_access import XControlAccess as XControlAccess
with suppress(ImportError):
    from ...dyn.view.x_form_layer_access import XFormLayerAccess as XFormLayerAccess
with suppress(ImportError):
    from ...dyn.view.x_line_cursor import XLineCursor as XLineCursor
with suppress(ImportError):
    from ...dyn.view.x_multi_selection_supplier import XMultiSelectionSupplier as XMultiSelectionSupplier
with suppress(ImportError):
    from ...dyn.view.x_print_job import XPrintJob as XPrintJob
with suppress(ImportError):
    from ...dyn.view.x_print_job_broadcaster import XPrintJobBroadcaster as XPrintJobBroadcaster
with suppress(ImportError):
    from ...dyn.view.x_print_job_listener import XPrintJobListener as XPrintJobListener
with suppress(ImportError):
    from ...dyn.view.x_print_settings_supplier import XPrintSettingsSupplier as XPrintSettingsSupplier
with suppress(ImportError):
    from ...dyn.view.x_printable import XPrintable as XPrintable
with suppress(ImportError):
    from ...dyn.view.x_printable_broadcaster import XPrintableBroadcaster as XPrintableBroadcaster
with suppress(ImportError):
    from ...dyn.view.x_printable_listener import XPrintableListener as XPrintableListener
with suppress(ImportError):
    from ...dyn.view.x_renderable import XRenderable as XRenderable
with suppress(ImportError):
    from ...dyn.view.x_screen_cursor import XScreenCursor as XScreenCursor
with suppress(ImportError):
    from ...dyn.view.x_selection_change_listener import XSelectionChangeListener as XSelectionChangeListener
with suppress(ImportError):
    from ...dyn.view.x_selection_supplier import XSelectionSupplier as XSelectionSupplier
with suppress(ImportError):
    from ...dyn.view.x_view_cursor import XViewCursor as XViewCursor
with suppress(ImportError):
    from ...dyn.view.x_view_settings_supplier import XViewSettingsSupplier as XViewSettingsSupplier



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing
from __future__ import annotations
import typing
from abc import abstractmethod
from ..container.x_index_access import XIndexAccess as XIndexAccess_f0910d6d
if typing.TYPE_CHECKING:
    from .x_layer import XLayer as XLayer_8fd00a49
    from .x_shape import XShape as XShape_8fd00a3d

class XLayerManager(XIndexAccess_f0910d6d):
    """
    This interface makes it possible to access and manage the Layers of a document.

    See Also:
        `API XLayerManager <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1drawing_1_1XLayerManager.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.XLayerManager'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.drawing.XLayerManager'

    @abstractmethod
    def attachShapeToLayer(self, xShape: XShape_8fd00a3d, xLayer: XLayer_8fd00a49) -> None:
        """
        attaches a Shape to the given Layer.
        """
        ...
    @abstractmethod
    def getLayerForShape(self, xShape: XShape_8fd00a3d) -> XLayer_8fd00a49:
        """
        queries the Layer that a Shape is attached to
        """
        ...
    @abstractmethod
    def insertNewByIndex(self, nIndex: int) -> XLayer_8fd00a49:
        """
        creates a new Layer
        """
        ...
    @abstractmethod
    def remove(self, xLayer: XLayer_8fd00a49) -> None:
        """
        removes a Layer and all Shapes on this Layer.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
        ...

__all__ = ['XLayerManager']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.lang
# Libre Office Version: 7.4
import typing
from .index_out_of_bounds_exception import IndexOutOfBoundsException as IndexOutOfBoundsException_66d010a9
from ..uno.x_interface import XInterface as XInterface_8f010a43

class ArrayIndexOutOfBoundsException(IndexOutOfBoundsException_66d010a9):
    """
    Exception Class

    This exception is thrown to indicate that an array has been accessed with an illegal index.
    
    The index is either negative or greater than or equal to the size of the array.

    See Also:
        `API ArrayIndexOutOfBoundsException <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1lang_1_1ArrayIndexOutOfBoundsException.html>`_
    """

    __ooo_ns__: str = 'com.sun.star.lang'
    __ooo_full_ns__: str = 'com.sun.star.lang.ArrayIndexOutOfBoundsException'
    __ooo_type_name__: str = 'exception'
    __pyunointerface__: str = 'com.sun.star.lang.ArrayIndexOutOfBoundsException'
    __pyunostruct__: str = 'com.sun.star.lang.ArrayIndexOutOfBoundsException'

    typeName: str = 'com.sun.star.lang.ArrayIndexOutOfBoundsException'
    """Literal Constant ``com.sun.star.lang.ArrayIndexOutOfBoundsException``"""

    def __init__(self, Message: typing.Optional[str] = '', Context: typing.Optional[XInterface_8f010a43] = None) -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
        """
        kargs = {
            "Message": Message,
            "Context": Context,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        super()._init(**kwargs)


__all__ = ['ArrayIndexOutOfBoundsException']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt.grid
from __future__ import annotations
import typing
from abc import abstractmethod, abstractproperty
from ...lang.x_component import XComponent as XComponent_98dc0ab5
from ...util.x_cloneable import XCloneable as XCloneable_99d00aa3

class XGridDataModel(XComponent_98dc0ab5, XCloneable_99d00aa3):
    """
    An instance of this interface is used by the UnoControlGrid to retrieve the content data that is displayed in the actual control.
    
    If you do not need your own model implementation, you can also use the DefaultGridDataModel.
    
    **since**
    
        OOo 3.3

    See Also:
        `API XGridDataModel <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1grid_1_1XGridDataModel.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt.grid'
    __ooo_full_ns__: str = 'com.sun.star.awt.grid.XGridDataModel'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.grid.XGridDataModel'

    @abstractmethod
    def getCellData(self, Column: int, RowIndex: int) -> object:
        """
        retrieves the data for a given cell

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...
    @abstractmethod
    def getCellToolTip(self, Column: int, RowIndex: int) -> object:
        """
        retrieves the tool tip to be displayed when the mouse hovers over a given cell
        
        At the moment, only string tool tips are supported.
        
        If VOID is returned here, the cell's content will be displayed as tip, but only if it does not fit into the cell.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...
    @abstractmethod
    def getRowData(self, RowIndex: int) -> typing.Tuple[object, ...]:
        """
        retrieves the data for a complete row
        
        This method is provided for performance and convenience reasons, it delivers the same result as subsequent calls to getCellData() would.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...
    @abstractmethod
    def getRowHeading(self, RowIndex: int) -> object:
        """
        retrieves the heading of a given row
        
        A grid control will usually paint a row's title in the header column of the respective row.
        
        At the moment, only strings are supported as row headings.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...
    @abstractproperty
    def ColumnCount(self) -> int:
        """
        denotes the number of columns for which the model can provide data
        """
        ...

    @abstractproperty
    def RowCount(self) -> int:
        """
        denotes the number of rows for which the model can provide data
        """
        ...


__all__ = ['XGridDataModel']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_sheet_filterable import XSheetFilterable as XSheetFilterable_eeed0d6c
if typing.TYPE_CHECKING:
    from .x_sheet_filter_descriptor import XSheetFilterDescriptor as XSheetFilterDescriptor_47cc0ff7

class XSheetFilterableEx(XSheetFilterable_eeed0d6c):
    """
    represents something from which criteria for filtering can be read.
    
    In general the current object will be used only to create the descriptor to filter another object, i.e. the advanced filter feature in a spreadsheet.

    See Also:
        `API XSheetFilterableEx <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetFilterableEx.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.XSheetFilterableEx'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sheet.XSheetFilterableEx'

    @abstractmethod
    def createFilterDescriptorByObject(self, xObject: XSheetFilterable_eeed0d6c) -> XSheetFilterDescriptor_47cc0ff7:
        """
        creates a filter descriptor for the specified filterable object from the contents of this object.
        """
        ...

__all__ = ['XSheetFilterableEx']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.script
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class InterruptReason(metaclass=UnoEnumMeta, type_name="com.sun.star.script.InterruptReason", name_space="com.sun.star.script"):
        """Dynamically created class that represents ``com.sun.star.script.InterruptReason`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.script.InterruptReason import BreakPoint as INTERRUPT_REASON_BreakPoint
        from com.sun.star.script.InterruptReason import Cancel as INTERRUPT_REASON_Cancel
        from com.sun.star.script.InterruptReason import CompileError as INTERRUPT_REASON_CompileError
        from com.sun.star.script.InterruptReason import RuntimeError as INTERRUPT_REASON_RuntimeError
        from com.sun.star.script.InterruptReason import Step as INTERRUPT_REASON_Step
        from com.sun.star.script.InterruptReason import StepOut as INTERRUPT_REASON_StepOut
        from com.sun.star.script.InterruptReason import StepOver as INTERRUPT_REASON_StepOver
        from com.sun.star.script.InterruptReason import StepStatement as INTERRUPT_REASON_StepStatement

        class InterruptReason(uno.Enum):
            """
            Enum Class


            See Also:
                `API InterruptReason <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1script.html#a298e9238891ddece524d1b3732aa33e4>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.script.InterruptReason', value)

            __ooo_ns__: str = 'com.sun.star.script'
            __ooo_full_ns__: str = 'com.sun.star.script.InterruptReason'
            __ooo_type_name__: str = 'enum'

            BreakPoint = INTERRUPT_REASON_BreakPoint
            """
            script stopped at a breakpoint.
            """
            Cancel = INTERRUPT_REASON_Cancel
            """
            script in the engine was cancelled.

            script execution was cancelled.
            """
            CompileError = INTERRUPT_REASON_CompileError
            """
            script has invalid syntax.
            """
            RuntimeError = INTERRUPT_REASON_RuntimeError
            """
            runtime error occurred during script execution.
            """
            Step = INTERRUPT_REASON_Step
            """
            script stops because only one scripting engine command was executed.
            """
            StepOut = INTERRUPT_REASON_StepOut
            """
            script stops because it leaves a function.
            """
            StepOver = INTERRUPT_REASON_StepOver
            """
            script stops because one step was executed.
            """
            StepStatement = INTERRUPT_REASON_StepStatement
            """
            script stop because one step was executed.
            """
    else:
        # keep document generators happy
        from ...lo.script.interrupt_reason import InterruptReason as InterruptReason


__all__ = ['InterruptReason']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.table
from __future__ import annotations
from abc import abstractmethod
from .x_cell_range import XCellRange as XCellRange_a2f70ad5

class XCellCursor(XCellRange_a2f70ad5):
    """
    provides methods to control the position of a cell cursor.

    See Also:
        `API XCellCursor <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1table_1_1XCellCursor.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.table'
    __ooo_full_ns__: str = 'com.sun.star.table.XCellCursor'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.table.XCellCursor'

    @abstractmethod
    def gotoEnd(self) -> None:
        """
        points the cursor to a single cell which is the end of a contiguous series of (filled) cells.
        """
        ...
    @abstractmethod
    def gotoNext(self) -> None:
        """
        points the cursor to the next unprotected cell.
        
        If the sheet is not protected, this is the next cell to the right.
        """
        ...
    @abstractmethod
    def gotoOffset(self, nColumnOffset: int, nRowOffset: int) -> None:
        """
        moves the origin of the cursor relative to the current position.
        """
        ...
    @abstractmethod
    def gotoPrevious(self) -> None:
        """
        points the cursor to the previous unprotected cell.
        
        If the sheet is not protected, this is the next cell to the left.
        """
        ...
    @abstractmethod
    def gotoStart(self) -> None:
        """
        points the cursor to a single cell which is the beginning of a contiguous series of (filled) cells.
        """
        ...

__all__ = ['XCellCursor']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from .enhanced_custom_shape_parameter_pair import EnhancedCustomShapeParameterPair as EnhancedCustomShapeParameterPair_262914a3


class EnhancedCustomShapeTextFrame(object):
    """
    Struct Class

    specifies the coordinates used with EnhancedCustomShapes

    See Also:
        `API EnhancedCustomShapeTextFrame <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeTextFrame.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.EnhancedCustomShapeTextFrame'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.drawing.EnhancedCustomShapeTextFrame'
    """Literal Constant ``com.sun.star.drawing.EnhancedCustomShapeTextFrame``"""

    def __init__(self, TopLeft: typing.Optional[EnhancedCustomShapeParameterPair_262914a3] = UNO_NONE, BottomRight: typing.Optional[EnhancedCustomShapeParameterPair_262914a3] = UNO_NONE) -> None:
        """
        Constructor

        Arguments:
            TopLeft (EnhancedCustomShapeParameterPair, optional): TopLeft value.
            BottomRight (EnhancedCustomShapeParameterPair, optional): BottomRight value.
        """
        super().__init__()

        if isinstance(TopLeft, EnhancedCustomShapeTextFrame):
            oth: EnhancedCustomShapeTextFrame = TopLeft
            self.TopLeft = oth.TopLeft
            self.BottomRight = oth.BottomRight
            return

        kargs = {
            "TopLeft": TopLeft,
            "BottomRight": BottomRight,
        }
        if kargs["TopLeft"] is UNO_NONE:
            kargs["TopLeft"] = None
        if kargs["BottomRight"] is UNO_NONE:
            kargs["BottomRight"] = None
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._top_left = kwargs["TopLeft"]
        self._bottom_right = kwargs["BottomRight"]


    @property
    def TopLeft(self) -> EnhancedCustomShapeParameterPair_262914a3:
        return self._top_left

    @TopLeft.setter
    def TopLeft(self, value: EnhancedCustomShapeParameterPair_262914a3) -> None:
        self._top_left = value

    @property
    def BottomRight(self) -> EnhancedCustomShapeParameterPair_262914a3:
        return self._bottom_right

    @BottomRight.setter
    def BottomRight(self, value: EnhancedCustomShapeParameterPair_262914a3) -> None:
        self._bottom_right = value


__all__ = ['EnhancedCustomShapeTextFrame']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.java.invalid_java_settings_exception import InvalidJavaSettingsException as InvalidJavaSettingsException
from ...lo.java.java_disabled_exception import JavaDisabledException as JavaDisabledException
from ...lo.java.java_initialization_exception import JavaInitializationException as JavaInitializationException
from ...lo.java.java_not_configured_exception import JavaNotConfiguredException as JavaNotConfiguredException
from ...lo.java.java_not_found_exception import JavaNotFoundException as JavaNotFoundException
from ...lo.java.java_vm_creation_failure_exception import JavaVMCreationFailureException as JavaVMCreationFailureException
from ...lo.java.java_virtual_machine import JavaVirtualMachine as JavaVirtualMachine
from ...lo.java.missing_java_runtime_exception import MissingJavaRuntimeException as MissingJavaRuntimeException
from ...lo.java.restart_required_exception import RestartRequiredException as RestartRequiredException
from ...lo.java.wrong_java_version_exception import WrongJavaVersionException as WrongJavaVersionException
from ...lo.java.x_java_thread_register_11 import XJavaThreadRegister_11 as XJavaThreadRegister_11
from ...lo.java.x_java_vm import XJavaVM as XJavaVM



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
import typing
from abc import abstractproperty
from .uno_control_model import UnoControlModel as UnoControlModel_c8ce0c58
if typing.TYPE_CHECKING:
    from .font_descriptor import FontDescriptor as FontDescriptor_bc110c0a
    from ..util.color import Color as Color_68e908c5
    from com.sun.star.style.VerticalAlignment import VerticalAlignmentProto

class UnoControlPatternFieldModel(UnoControlModel_c8ce0c58):
    """
    Service Class

    specifies the standard model of a UnoControlPatternField.
    
    **since**
    
        OOo 2.0

    See Also:
        `API UnoControlPatternFieldModel <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlPatternFieldModel.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.UnoControlPatternFieldModel'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def BackgroundColor(self) -> Color_68e908c5:
        """
        specifies the background color (RGB) of the control.
        """
        ...

    @abstractproperty
    def Border(self) -> int:
        """
        specifies the border style of the control.
        """
        ...

    @abstractproperty
    def BorderColor(self) -> int:
        """
        specifies the color of the border, if present
        
        Not every border style (see Border) may support coloring. For instance, usually a border with 3D effect will ignore the BorderColor setting.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def EditMask(self) -> str:
        """
        specifies the edit mask.
        """
        ...

    @abstractproperty
    def Enabled(self) -> bool:
        """
        determines whether the control is enabled or disabled.
        """
        ...

    @abstractproperty
    def FontDescriptor(self) -> FontDescriptor_bc110c0a:
        """
        specifies the font attributes of the text in the control.
        """
        ...

    @abstractproperty
    def FontEmphasisMark(self) -> int:
        """
        specifies the com.sun.star.text.FontEmphasis value of the text in the control.
        """
        ...

    @abstractproperty
    def FontRelief(self) -> int:
        """
        specifies the com.sun.star.text.FontRelief value of the text in the control.
        """
        ...

    @abstractproperty
    def HelpText(self) -> str:
        """
        specifies the help text of the control.
        """
        ...

    @abstractproperty
    def HelpURL(self) -> str:
        """
        specifies the help URL of the control.
        """
        ...

    @abstractproperty
    def HideInactiveSelection(self) -> bool:
        """
        specifies whether the selection in the control should be hidden when the control is not active (focused).
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def LiteralMask(self) -> str:
        """
        specifies the literal mask.
        """
        ...

    @abstractproperty
    def MaxTextLen(self) -> int:
        """
        specifies the maximum character count.
        """
        ...

    @abstractproperty
    def MouseWheelBehavior(self) -> int:
        """
        defines how the mouse wheel can be used to scroll through the control's content.
        
        Usually, the mouse wheel spins the numeric value displayed in the control. Using this property, and one of the MouseWheelBehavior constants, you can control under which circumstances this is possible.
        """
        ...

    @abstractproperty
    def Printable(self) -> bool:
        """
        specifies that the control will be printed with the document.
        """
        ...

    @abstractproperty
    def ReadOnly(self) -> bool:
        """
        specifies that the content of the control cannot be modified by the user.
        """
        ...

    @abstractproperty
    def StrictFormat(self) -> bool:
        """
        specifies that the text is checked during the user input.
        """
        ...

    @abstractproperty
    def Tabstop(self) -> bool:
        """
        specifies that the control can be reached with the TAB key.
        """
        ...

    @abstractproperty
    def Text(self) -> str:
        """
        specifies the text displayed in the control.
        """
        ...

    @abstractproperty
    def TextColor(self) -> Color_68e908c5:
        """
        specifies the text color (RGB) of the control.
        """
        ...

    @abstractproperty
    def TextLineColor(self) -> Color_68e908c5:
        """
        specifies the text line color (RGB) of the control.
        """
        ...

    @abstractproperty
    def VerticalAlign(self) -> VerticalAlignmentProto:
        """
        specifies the vertical alignment of the text in the control.
        
        **since**
        
            OOo 3.3
        """
        ...

    @abstractproperty
    def WritingMode(self) -> int:
        """
        denotes the writing mode used in the control, as specified in the com.sun.star.text.WritingMode2 constants group.
        
        Only com.sun.star.text.WritingMode2.LR_TB and com.sun.star.text.WritingMode2.RL_TB are supported at the moment.
        
        **since**
        
            OOo 3.1
        """
        ...


__all__ = ['UnoControlPatternFieldModel']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.accessibility
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_accessible_text import XAccessibleText as XAccessibleText_5b77105b
if typing.TYPE_CHECKING:
    from .x_accessible_hyperlink import XAccessibleHyperlink as XAccessibleHyperlink_b34c126c

class XAccessibleHypertext(XAccessibleText_5b77105b):
    """
    Implement this interface to expose the hypertext structure of a document.
    
    The XAccessibleHypertext interface is the main interface to expose hyperlinks in a document, typically a text document, that are used to reference other (parts of) documents. For supporting the XAccessibleHypertext.getLinkIndex() method of this interface and other character related methods of the XAccessibleHyperlink interface, it is necessary to also support the XAccessibleText interface.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XAccessibleHypertext <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1accessibility_1_1XAccessibleHypertext.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.accessibility'
    __ooo_full_ns__: str = 'com.sun.star.accessibility.XAccessibleHypertext'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.accessibility.XAccessibleHypertext'

    @abstractmethod
    def getHyperLink(self, nLinkIndex: int) -> XAccessibleHyperlink_b34c126c:
        """
        Return the specified link.
        
        The returned XAccessibleHyperlink object encapsulates the hyperlink and provides several kinds of information describing it.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...
    @abstractmethod
    def getHyperLinkCount(self) -> int:
        """
        Returns the number of links and link groups contained within this hypertext document.
        """
        ...
    @abstractmethod
    def getHyperLinkIndex(self, nCharIndex: int) -> int:
        """
        Returns the index of the hyperlink that is associated with this character index.
        
        In a HTML document this is the case when a <a href> tag spans (includes) the given character index.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...

__all__ = ['XAccessibleHypertext']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
from .open_command_argument2 import OpenCommandArgument2 as OpenCommandArgument2_9210e08
from ..beans.property import Property as Property_8f4e0a76
from ..uno.x_interface import XInterface as XInterface_8f010a43
from .numbered_sorting_info import NumberedSortingInfo as NumberedSortingInfo_fd0e0de6
import typing
from ..beans.named_value import NamedValue as NamedValue_a37a0af3


class OpenCommandArgument3(OpenCommandArgument2_9210e08):
    """
    Struct Class

    Extended argument for commands like \"open\".
    
    We're extending OpenCommandArgument even more, to provide some opening flags on to webdav.

    See Also:
        `API OpenCommandArgument3 <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1OpenCommandArgument3.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.OpenCommandArgument3'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.ucb.OpenCommandArgument3'
    """Literal Constant ``com.sun.star.ucb.OpenCommandArgument3``"""

    def __init__(self, Properties: typing.Optional[typing.Tuple[Property_8f4e0a76, ...]] = (), Mode: typing.Optional[int] = 0, Priority: typing.Optional[int] = 0, Sink: typing.Optional[XInterface_8f010a43] = None, SortingInfo: typing.Optional[typing.Tuple[NumberedSortingInfo_fd0e0de6, ...]] = (), OpeningFlags: typing.Optional[typing.Tuple[NamedValue_a37a0af3, ...]] = ()) -> None:
        """
        Constructor

        Arguments:
            Properties (typing.Tuple[Property, ...], optional): Properties value.
            Mode (int, optional): Mode value.
            Priority (int, optional): Priority value.
            Sink (XInterface, optional): Sink value.
            SortingInfo (typing.Tuple[NumberedSortingInfo, ...], optional): SortingInfo value.
            OpeningFlags (typing.Tuple[NamedValue, ...], optional): OpeningFlags value.
        """

        if isinstance(Properties, OpenCommandArgument3):
            oth: OpenCommandArgument3 = Properties
            self.Properties = oth.Properties
            self.Mode = oth.Mode
            self.Priority = oth.Priority
            self.Sink = oth.Sink
            self.SortingInfo = oth.SortingInfo
            self.OpeningFlags = oth.OpeningFlags
            return

        kargs = {
            "Properties": Properties,
            "Mode": Mode,
            "Priority": Priority,
            "Sink": Sink,
            "SortingInfo": SortingInfo,
            "OpeningFlags": OpeningFlags,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._opening_flags = kwargs["OpeningFlags"]
        inst_keys = ('OpeningFlags',)
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)


    @property
    def OpeningFlags(self) -> typing.Tuple[NamedValue_a37a0af3, ...]:
        """
        Flags to use for opening.
        
        WebDav e.g. uses \"KeepAlive\" to enable/disable the respective http feature.
        """
        return self._opening_flags

    @OpeningFlags.setter
    def OpeningFlags(self, value: typing.Tuple[NamedValue_a37a0af3, ...]) -> None:
        self._opening_flags = value


__all__ = ['OpenCommandArgument3']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.form.component
from __future__ import annotations
import typing
from abc import abstractproperty
from ..data_aware_control_model import DataAwareControlModel as DataAwareControlModel_27110ef8
from .combo_box import ComboBox as ComboBox_fecc0dd6
if typing.TYPE_CHECKING:
    from com.sun.star.form.ListSourceType import ListSourceTypeProto

class DatabaseComboBox(DataAwareControlModel_27110ef8, ComboBox_fecc0dd6):
    """
    Service Class

    This service specifies a combo box which is data-aware, and can be bound to a database field.
    
    Like most other data aware controls, such a combo box will display the actual content of the field it is bound to. In addition, as a combo box contains a list where the user can choose items to fill into the control, this list can be filled with different data from a database, too.

    See Also:
        `API DatabaseComboBox <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1component_1_1DatabaseComboBox.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form.component'
    __ooo_full_ns__: str = 'com.sun.star.form.component.DatabaseComboBox'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def ConvertEmptyToNull(self) -> bool:
        """
        determines if an empty text should be treated as a NULL value.
        
        When the user enters text into a combo box, and after this, the control content is to be committed into the database field the control is bound to, a decision must be made how to deal with empty strings.This is controlled by ConvertEmptyToNull.
        
        If the property is set to TRUE, and an empty text is to be committed, this is converted into NULL, else it is written as empty string.
        """
        ...

    @abstractproperty
    def ListSource(self) -> str:
        """
        describes the source of items in the combo box's list.
        
        The concrete meaning of this property depends on the value of ListSourceType
        """
        ...

    @abstractproperty
    def ListSourceType(self) -> ListSourceTypeProto:
        """
        specifies the kind of list source.
        
        Note: A value of com.sun.star.form.ListSourceType.VALUELIST is not valid for a combo box. It won't be rejected when setting it, but controls will usually ignore it and leave the list empty.
        """
        ...


__all__ = ['DatabaseComboBox']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.document
from __future__ import annotations
from .x_extended_filter_detection import XExtendedFilterDetection as XExtendedFilterDetection_9ff211f5

class ExtendedTypeDetection(XExtendedFilterDetection_9ff211f5):
    """
    Service Class

    describes a class of service which will be used for deep TypeDetection in a generic way
    
    Due to the registered types, flat TypeDetection is already possible, i.e. the assignment of types (e.g. to a URL) only on the basis of configuration data. If, however, you imagine special cases (e.g. modifying the file extension of a Writer file from .sdw to .doc), it quickly becomes clear that you cannot always get a correct result with flat detection. To be certain to get correct results, you need deep detection, i.e. the file itself has to be examined. And that is exactly the function of DetectServices. They get all the information collected so far on a document and then decide which type to assign it to. In the new modular model, such a detector is meant as UNO service which registers itself in the office and is requested by the generic type detection if necessary. Therefore you need two pieces of information:
    
    See service TypeDetection and his configuration for further information.

    See Also:
        `API ExtendedTypeDetection <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1document_1_1ExtendedTypeDetection.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.document'
    __ooo_full_ns__: str = 'com.sun.star.document.ExtendedTypeDetection'
    __ooo_type_name__: str = 'service'


__all__ = ['ExtendedTypeDetection']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
from __future__ import annotations
import typing
from abc import abstractproperty
from .base_frame import BaseFrame as BaseFrame_8f020a33
from .x_text_frame import XTextFrame as XTextFrame_9a7e0ab5
if typing.TYPE_CHECKING:
    from .x_text import XText as XText_690408ca
    from com.sun.star.drawing.TextVerticalAdjust import TextVerticalAdjustProto

class TextFrame(BaseFrame_8f020a33, XTextFrame_9a7e0ab5):
    """
    Service Class

    specifies a rectangular shape which contains a Text object and is attached to a piece of surrounding Text.
    
    This example shows how to create a TextFrame and insert it at the very beginning of Text component. The macro is ready to run, if it is a script within a text document.
    
    **since**
    
        LibreOffice 6.3

    See Also:
        `API TextFrame <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1TextFrame.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.TextFrame'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def EditInReadonly(self) -> bool:
        """
        determines if the text frame should be editable in a read-only document.
        
        (This is usually used in forms.)
        """
        ...

    @abstractproperty
    def FrameHeightAbsolute(self) -> int:
        """
        contains the metric height value of the frame.
        """
        ...

    @abstractproperty
    def FrameHeightPercent(self) -> int:
        """
        specifies a width relative to the width of the surrounding text.
        
        If the value for \"HeightPercent\" is 0, the absolute value from is used.
        """
        ...

    @abstractproperty
    def FrameIsAutomaticHeight(self) -> bool:
        """
        If \"AutomaticHeight\" is set, then the object grows if it is required by the frame content.
        """
        ...

    @abstractproperty
    def FrameWidthAbsolute(self) -> int:
        """
        contains the metric width value of the frame.
        """
        ...

    @abstractproperty
    def FrameWidthPercent(self) -> int:
        """
        specifies a width relative to the width of the surrounding text.
        
        If the value for \"WidthPercent\" is 0, the absolute value from is used.
        """
        ...

    @abstractproperty
    def IsFollowingTextFlow(self) -> bool:
        """
        controls, if the frame follows the text flow or can leave its layout environment
        
        If set, the frame follows the text flow and doesn't leaves the layout environment, which is given by its anchor, above and below. E.g.: Anchor resides in the document body then the frame doesn't leave the document body above and below and follows the text flow through the document bodies of the different pages.
        
        If not set, the frame doesn't follow the text flow and stays on the page, on which its anchor is found, but it may leave the layout environment, which is given by its anchor. E.g.: Anchor resides in the document body then the frame stays on page, where this document body is, but it could leave the document body above and below, e.g. overlapping with the page header.
        
        Note: The areas for the vertical orientation relation at page areas are interpreted in dependence to this property (
        """
        ...

    @abstractproperty
    def ParentText(self) -> XText_690408ca:
        """
        Parent text of this text frame.
        
        This might be a header text, body text, etc.
        
        **since**
        
            LibreOffice 6.3
        """
        ...

    @abstractproperty
    def SizeType(self) -> int:
        """
        determines the interpretation of the height and relative height properties.
        """
        ...

    @abstractproperty
    def TextVerticalAdjust(self) -> TextVerticalAdjustProto:
        """
        adjusts the vertical position of the text inside of the frame.
        
        **since**
        
            LibreOffice 4.3
        """
        ...

    @abstractproperty
    def WidthType(self) -> int:
        """
        determines the interpretation of the width and relative width properties.
        
        **since**
        
            OOo 2.4
        """
        ...

    @abstractproperty
    def WritingMode(self) -> int:
        """
        contains the writing direction, as represented by the com.sun.star.text.WritingMode2 constants
        """
        ...


__all__ = ['TextFrame']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.i18n


class CalendarDisplayIndex(object):
    """
    Const Class

    Values to be passed to XCalendar.getDisplayName().
    
    **since**
    
        LibreOffice 3.5

    See Also:
        `API CalendarDisplayIndex <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n_1_1CalendarDisplayIndex.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.CalendarDisplayIndex'
    __ooo_type_name__: str = 'const'

    AM_PM = 0
    """
    name of an AM/PM value
    """
    DAY = 1
    """
    name of a day of week
    """
    MONTH = 2
    """
    name of a month
    """
    YEAR = 3
    """
    name of a year (if used for a specific calendar)
    """
    ERA = 4
    """
    name of an era, like BC/AD
    """
    GENITIVE_MONTH = 5
    """
    name of a possessive genitive case month
    
    **since**
    
        LibreOffice 3.5
    """
    PARTITIVE_MONTH = 6
    """
    name of a partitive case month
    
    **since**
    
        LibreOffice 3.5
    """

__all__ = ['CalendarDisplayIndex']
